@@ -7,7 +7,7 @@
 //!
 //! ```toml
 //! [dependencies.iced-x86]
-//! version = "1.15.0"
+//! version = "1.16.0"
 //! features = ["code_asm"]
 //! ```
 //!
@@ -15,10 +15,10 @@
 //!
 //! [`CodeAssembler`]: struct.CodeAssembler.html
 
+pub mod asm_traits;
 mod code_asm_methods;
 mod fn_asm_impl;
 mod fn_asm_pub;
-mod fn_asm_traits;
 mod mem;
 mod op_state;
 mod reg;
@@ -57,7 +57,7 @@ impl CodeAssemblerOptions {
 ///
 /// ```toml
 /// [dependencies.iced-x86]
-/// version = "1.15.0"
+/// version = "1.16.0"
 /// features = ["code_asm"]
 /// ```
 ///
