@@ -10,7 +10,6 @@ use crate::code_asm::{CodeAssembler, CodeAssemblerOptions, CodeLabel, PrefixFlag
 use crate::IcedError;
 use crate::{BlockEncoder, BlockEncoderOptions, Code, Instruction, InstructionBlock, MemoryOperand, Register};
 use alloc::vec::Vec;
-use core::usize;
 
 impl CodeAssembler {
 	const MAX_DB_COUNT: usize = 16;
@@ -51,7 +50,7 @@ impl CodeAssembler {
 	#[must_use]
 	#[inline]
 	pub fn xacquire(&mut self) -> &mut Self {
-		self.prefix_flags |= PrefixFlags::XACQUIRE;
+		self.prefix_flags |= PrefixFlags::REPNE;
 		self
 	}
 
@@ -59,7 +58,7 @@ impl CodeAssembler {
 	#[must_use]
 	#[inline]
 	pub fn xrelease(&mut self) -> &mut Self {
-		self.prefix_flags |= PrefixFlags::XRELEASE;
+		self.prefix_flags |= PrefixFlags::REPE;
 		self
 	}
 
@@ -96,7 +95,7 @@ impl CodeAssembler {
 		self
 	}
 
-	/// Adds a `REPE` prefix to the next added instruction
+	/// Adds a `REPE`/`REPZ` prefix to the next added instruction
 	///
 	/// # Examples
 	///
@@ -121,7 +120,31 @@ impl CodeAssembler {
 		self
 	}
 
-	/// Adds a `REPNE` prefix to the next added instruction
+	/// Adds a `REPE`/`REPZ` prefix to the next added instruction
+	///
+	/// # Examples
+	///
+	/// ```
+	/// use iced_x86::code_asm::*;
+	///
+	/// # fn main() -> Result<(), IcedError> {
+	/// let mut a = CodeAssembler::new(64)?;
+	///
+	/// a.repz().cmpsb()?;
+	/// a.nop()?;
+	///
+	/// let bytes = a.assemble(0x1234_5678)?;
+	/// assert_eq!(bytes, vec![0xF3, 0xA6, 0x90]);
+	/// # Ok(())
+	/// # }
+	/// ```
+	#[must_use]
+	#[inline]
+	pub fn repz(&mut self) -> &mut Self {
+		self.repe()
+	}
+
+	/// Adds a `REPNE`/`REPNZ` prefix to the next added instruction
 	///
 	/// # Examples
 	///
@@ -146,6 +169,30 @@ impl CodeAssembler {
 		self
 	}
 
+	/// Adds a `REPNE`/`REPNZ` prefix to the next added instruction
+	///
+	/// # Examples
+	///
+	/// ```
+	/// use iced_x86::code_asm::*;
+	///
+	/// # fn main() -> Result<(), IcedError> {
+	/// let mut a = CodeAssembler::new(64)?;
+	///
+	/// a.repnz().scasb()?;
+	/// a.nop()?;
+	///
+	/// let bytes = a.assemble(0x1234_5678)?;
+	/// assert_eq!(bytes, vec![0xF2, 0xAE, 0x90]);
+	/// # Ok(())
+	/// # }
+	/// ```
+	#[must_use]
+	#[inline]
+	pub fn repnz(&mut self) -> &mut Self {
+		self.repne()
+	}
+
 	/// Adds a `BND` prefix to the next added instruction
 	#[must_use]
 	#[inline]
@@ -162,6 +209,58 @@ impl CodeAssembler {
 		self
 	}
 
+	/// Prefer `VEX` encoding if the next instruction can be `VEX` and `EVEX` encoded
+	///
+	/// # Examples
+	///
+	/// ```
+	/// use iced_x86::code_asm::*;
+	///
+	/// # fn main() -> Result<(), IcedError> {
+	/// let mut a = CodeAssembler::new(64)?;
+	///
+	/// // This instruction can be VEX and EVEX encoded
+	/// a.vex().vaddpd(xmm1, xmm2, xmm3)?;
+	/// a.evex().vaddpd(xmm1, xmm2, xmm3)?;
+	///
+	/// let bytes = a.assemble(0x1234_5678)?;
+	/// assert_eq!(bytes, b"\xC5\xE9\x58\xCB\x62\xF1\xED\x08\x58\xCB");
+	/// # Ok(())
+	/// # }
+	/// ```
+	#[must_use]
+	#[inline]
+	pub fn vex(&mut self) -> &mut Self {
+		self.prefix_flags |= PrefixFlags::PREFER_VEX;
+		self
+	}
+
+	/// Prefer `EVEX` encoding if the next instruction can be `VEX` and `EVEX` encoded
+	///
+	/// # Examples
+	///
+	/// ```
+	/// use iced_x86::code_asm::*;
+	///
+	/// # fn main() -> Result<(), IcedError> {
+	/// let mut a = CodeAssembler::new(64)?;
+	///
+	/// // This instruction can be VEX and EVEX encoded
+	/// a.vex().vaddpd(xmm1, xmm2, xmm3)?;
+	/// a.evex().vaddpd(xmm1, xmm2, xmm3)?;
+	///
+	/// let bytes = a.assemble(0x1234_5678)?;
+	/// assert_eq!(bytes, b"\xC5\xE9\x58\xCB\x62\xF1\xED\x08\x58\xCB");
+	/// # Ok(())
+	/// # }
+	/// ```
+	#[must_use]
+	#[inline]
+	pub fn evex(&mut self) -> &mut Self {
+		self.prefix_flags |= PrefixFlags::PREFER_EVEX;
+		self
+	}
+
 	/// Gets all added instructions, see also [`take_instructions()`] and [`assemble()`]
 	///
 	/// [`take_instructions()`]: #method.take_instructions
@@ -767,7 +866,7 @@ impl CodeAssembler {
 		Ok(())
 	}
 
-	/// Adds nops, preferring long nops over short nops
+	/// Adds nops, preferring long nops
 	///
 	/// # Errors
 	///
@@ -914,12 +1013,6 @@ impl CodeAssembler {
 		}
 
 		if self.prefix_flags != 0 {
-			if (self.prefix_flags & PrefixFlags::XACQUIRE) != 0 {
-				instruction.set_has_xacquire_prefix(true);
-			}
-			if (self.prefix_flags & PrefixFlags::XRELEASE) != 0 {
-				instruction.set_has_xrelease_prefix(true);
-			}
 			if (self.prefix_flags & PrefixFlags::LOCK) != 0 {
 				instruction.set_has_lock_prefix(true);
 			}
@@ -1003,14 +1096,20 @@ impl CodeAssembler {
 		self.bitness
 	}
 
-	/// `true` (default value) to use `VEX` encoding intead of `EVEX` encoding if we must pick one of the encodings
+	/// `true` (default value) to use `VEX` encoding intead of `EVEX` encoding if we must pick one of the encodings. See also [`vex()`] and [`evex()`]
+	///
+	/// [`vex()`]: #method.vex
+	/// [`evex()`]: #method.evex
 	#[must_use]
 	#[inline]
 	pub fn prefer_vex(&self) -> bool {
 		(self.options & CodeAssemblerOptions::PREFER_VEX) != 0
 	}
 
-	/// `true` (default value) to use `VEX` encoding intead of `EVEX` encoding if we must pick one of the encodings
+	/// `true` (default value) to use `VEX` encoding intead of `EVEX` encoding if we must pick one of the encodings. See also [`vex()`] and [`evex()`]
+	///
+	/// [`vex()`]: #method.vex
+	/// [`evex()`]: #method.evex
 	///
 	/// # Arguments
 	///
@@ -1045,6 +1144,15 @@ impl CodeAssembler {
 		}
 	}
 
+	#[inline]
+	pub(crate) fn instruction_prefer_vex(&self) -> bool {
+		if (self.prefix_flags & (PrefixFlags::PREFER_VEX | PrefixFlags::PREFER_EVEX)) != 0 {
+			(self.prefix_flags & PrefixFlags::PREFER_VEX) != 0
+		} else {
+			(self.options & CodeAssemblerOptions::PREFER_VEX) != 0
+		}
+	}
+
 	/// `CALL FAR` instruction
 	///
 	/// Instruction | Opcode | CPUID
