@@ -9,6 +9,7 @@ use crate::iced_constants::IcedConstants;
 use crate::*;
 use alloc::boxed::Box;
 use alloc::vec::Vec;
+use core::convert::TryInto;
 use core::mem;
 use lazy_static::lazy_static;
 
@@ -21,7 +22,7 @@ lazy_static! {
 			let enc_flags2 = ENC_FLAGS2[code as usize];
 			let enc_flags3 = ENC_FLAGS3[code as usize];
 			// SAFETY: The table is generated and only contains valid enum variants
-			let encoding: EncodingKind = unsafe { mem::transmute(((enc_flags3 >> EncFlags3::ENCODING_SHIFT) & EncFlags3::ENCODING_MASK) as u8) };
+			let encoding: EncodingKind = unsafe { mem::transmute(((enc_flags3 >> EncFlags3::ENCODING_SHIFT) & EncFlags3::ENCODING_MASK) as EncodingKindUnderlyingType) };
 			let handler = match encoding {
 				EncodingKind::Legacy => {
 					if code == Code::INVALID {
@@ -48,12 +49,14 @@ lazy_static! {
 				EncodingKind::D3NOW => Box::into_raw(Box::new(D3nowHandler::new(enc_flags2, enc_flags3))) as *const OpCodeHandler,
 				#[cfg(feature = "no_d3now")]
 				EncodingKind::D3NOW => invalid_handler,
+				#[cfg(feature = "mvex")]
+				EncodingKind::MVEX => Box::into_raw(Box::new(MvexHandler::new(enc_flags1, enc_flags2, enc_flags3))) as *const OpCodeHandler,
+				#[cfg(not(feature = "mvex"))]
+				EncodingKind::MVEX => invalid_handler,
 			};
 			v.push(unsafe { &*handler });
 		}
-		let v = v.into_boxed_slice();
-		debug_assert_eq!(v.len(), IcedConstants::CODE_ENUM_COUNT);
-		// SAFETY: Size is verified above
-		unsafe { Box::from_raw(Box::into_raw(v) as *mut [_; IcedConstants::CODE_ENUM_COUNT]) }
+		#[allow(clippy::unwrap_used)]
+		v.into_boxed_slice().try_into().ok().unwrap()
 	};
 }
