@@ -29,7 +29,7 @@ use crate::*;
 use alloc::boxed::Box;
 use alloc::vec::Vec;
 use core::marker::PhantomData;
-use core::{mem, ptr, slice, u16, u32, u8, usize};
+use core::{mem, ptr, slice};
 use static_assertions::{const_assert, const_assert_eq};
 
 // full fmt'd str = "prefixes mnemonic op0<decorators1>, op1, op2, op3, op4<decorators2>"
@@ -53,8 +53,8 @@ use static_assertions::{const_assert, const_assert_eq};
 const MAX_FMT_INSTR_LEN: usize = {
 	const MAX_PREFIXES_LEN: usize = "es xacquire xrelease lock notrack repe repne ".len();
 	const MAX_OPERAND_LEN: usize = "fpustate108 ptr fs:[rax+zmm31*8+0x12345678]".len();
-	const MAX_DECORATOR1_LEN: usize = "{k3}{z}".len();
-	const MAX_DECORATOR2_LEN: usize = "{rn-sae}".len();
+	const MAX_DECORATOR1_LEN: usize = "{k3}{z}{eh}".len();
+	const MAX_DECORATOR2_LEN: usize = "{rn-sae}{float16}".len();
 
 	MAX_PREFIXES_LEN
 	+ crate::formatter::strings_data::MAX_STRING_LEN
@@ -67,11 +67,11 @@ const_assert_eq!(
 	// Max mnemonic len
 	crate::formatter::strings_data::MAX_STRING_LEN
 		+ "es xacquire xrelease lock notrack repe repne  \
-			fpustate108 ptr fs:[rax+zmm31*8+0x12345678]{k3}{z}, \
+			fpustate108 ptr fs:[rax+zmm31*8+0x12345678]{k3}{z}{eh}, \
 			fpustate108 ptr fs:[rax+zmm31*8+0x12345678], \
 			fpustate108 ptr fs:[rax+zmm31*8+0x12345678], \
 			fpustate108 ptr fs:[rax+zmm31*8+0x12345678], \
-			fpustate108 ptr fs:[rax+zmm31*8+0x12345678]{rn-sae}"
+			fpustate108 ptr fs:[rax+zmm31*8+0x12345678]{rn-sae}{float16}"
 			.len()
 );
 // Make sure it doesn't grow too much without us knowing about it (eg. if more operands are added)
@@ -300,24 +300,24 @@ macro_rules! use_dst_next_p_now {
 
 // Macros to safely call the methods (make sure the return value is stored back in dst_next_p)
 macro_rules! call_format_register {
-	($slf:ident, $dst:ident, $dst_next_p:ident, $reg:expr) => {
+	($slf:ident, $dst:ident, $dst_next_p:ident, $reg:expr) => {{
 		$dst_next_p = $slf.format_register($dst, $dst_next_p, $reg);
-	};
+	}};
 }
 macro_rules! call_format_number {
-	($slf:ident, $dst:ident, $dst_next_p:ident, $imm:expr) => {
+	($slf:ident, $dst:ident, $dst_next_p:ident, $imm:expr) => {{
 		$dst_next_p = $slf.format_number($dst, $dst_next_p, $imm);
-	};
+	}};
 }
 macro_rules! call_write_symbol {
-	($slf:ident, $dst:ident, $dst_next_p:ident, $imm:expr, $sym:expr) => {
+	($slf:ident, $dst:ident, $dst_next_p:ident, $imm:expr, $sym:expr) => {{
 		$dst_next_p = $slf.write_symbol($dst, $dst_next_p, $imm, $sym);
-	};
+	}};
 }
 macro_rules! call_write_symbol2 {
-	($slf:ident, $dst:ident, $dst_next_p:ident, $imm:expr, $sym:expr, $write_minus_if_signed:literal) => {
+	($slf:ident, $dst:ident, $dst_next_p:ident, $imm:expr, $sym:expr, $write_minus_if_signed:literal) => {{
 		$dst_next_p = $slf.write_symbol2($dst, $dst_next_p, $imm, $sym, $write_minus_if_signed);
-	};
+	}};
 }
 macro_rules! format_memory_else_block {
 	($slf:ident, $dst:ident, $dst_next_p:ident, $need_plus:ident, $displ_size:ident, $displ:ident, $addr_size:ident) => {
@@ -521,13 +521,60 @@ const_assert_eq!(RoundingControl::RoundToNearest as u32, 1);
 const_assert_eq!(RoundingControl::RoundDown as u32, 2);
 const_assert_eq!(RoundingControl::RoundUp as u32, 3);
 const_assert_eq!(RoundingControl::RoundTowardZero as u32, 4);
-static RC_STRINGS: [FastString8; 5] = [
-	mk_const_fast_str!(FastString8, "\x08        "),
+static RC_SAE_STRINGS: [FastString8; IcedConstants::ROUNDING_CONTROL_ENUM_COUNT] = [
+	mk_const_fast_str!(FastString8, "\x00        "),
 	mk_const_fast_str!(FastString8, "\x08{rn-sae}"),
 	mk_const_fast_str!(FastString8, "\x08{rd-sae}"),
 	mk_const_fast_str!(FastString8, "\x08{ru-sae}"),
 	mk_const_fast_str!(FastString8, "\x08{rz-sae}"),
 ];
+static RC_STRINGS: [FastString4; IcedConstants::ROUNDING_CONTROL_ENUM_COUNT] = [
+	mk_const_fast_str!(FastString4, "\x00    "),
+	mk_const_fast_str!(FastString4, "\x04{rn}"),
+	mk_const_fast_str!(FastString4, "\x04{rd}"),
+	mk_const_fast_str!(FastString4, "\x04{ru}"),
+	mk_const_fast_str!(FastString4, "\x04{rz}"),
+];
+#[cfg(feature = "mvex")]
+static MVEX_REG_MEM_CONSTS_32: [FastString12; IcedConstants::MVEX_REG_MEM_CONV_ENUM_COUNT] = [
+	mk_const_fast_str!(FastString12, "\x00            "),
+	mk_const_fast_str!(FastString12, "\x00            "),
+	mk_const_fast_str!(FastString12, "\x06{cdab}      "),
+	mk_const_fast_str!(FastString12, "\x06{badc}      "),
+	mk_const_fast_str!(FastString12, "\x06{dacb}      "),
+	mk_const_fast_str!(FastString12, "\x06{aaaa}      "),
+	mk_const_fast_str!(FastString12, "\x06{bbbb}      "),
+	mk_const_fast_str!(FastString12, "\x06{cccc}      "),
+	mk_const_fast_str!(FastString12, "\x06{dddd}      "),
+	mk_const_fast_str!(FastString12, "\x00            "),
+	mk_const_fast_str!(FastString12, "\x07{1to16}     "),
+	mk_const_fast_str!(FastString12, "\x07{4to16}     "),
+	mk_const_fast_str!(FastString12, "\x09{float16}   "),
+	mk_const_fast_str!(FastString12, "\x07{uint8}     "),
+	mk_const_fast_str!(FastString12, "\x07{sint8}     "),
+	mk_const_fast_str!(FastString12, "\x08{uint16}    "),
+	mk_const_fast_str!(FastString12, "\x08{sint16}    "),
+];
+#[cfg(feature = "mvex")]
+static MVEX_REG_MEM_CONSTS_64: [FastString12; IcedConstants::MVEX_REG_MEM_CONV_ENUM_COUNT] = [
+	mk_const_fast_str!(FastString12, "\x00            "),
+	mk_const_fast_str!(FastString12, "\x00            "),
+	mk_const_fast_str!(FastString12, "\x06{cdab}      "),
+	mk_const_fast_str!(FastString12, "\x06{badc}      "),
+	mk_const_fast_str!(FastString12, "\x06{dacb}      "),
+	mk_const_fast_str!(FastString12, "\x06{aaaa}      "),
+	mk_const_fast_str!(FastString12, "\x06{bbbb}      "),
+	mk_const_fast_str!(FastString12, "\x06{cccc}      "),
+	mk_const_fast_str!(FastString12, "\x06{dddd}      "),
+	mk_const_fast_str!(FastString12, "\x00            "),
+	mk_const_fast_str!(FastString12, "\x06{1to8}      "),
+	mk_const_fast_str!(FastString12, "\x06{4to8}      "),
+	mk_const_fast_str!(FastString12, "\x09{float16}   "),
+	mk_const_fast_str!(FastString12, "\x07{uint8}     "),
+	mk_const_fast_str!(FastString12, "\x07{sint8}     "),
+	mk_const_fast_str!(FastString12, "\x08{uint16}    "),
+	mk_const_fast_str!(FastString12, "\x08{sint16}    "),
+];
 
 struct FmtTableData {
 	mnemonics: Box<[FastStringMnemonic; IcedConstants::CODE_ENUM_COUNT]>,
@@ -707,25 +754,6 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 		SpecializedFormatter::<TraitOptions>::try_with_options(None).unwrap()
 	}
 
-	/// Creates a new instance of this formatter
-	///
-	/// # Panics
-	///
-	/// Panics if [`TraitOptions::ENABLE_SYMBOL_RESOLVER`] is `false` and `symbol_resolver.is_some()`
-	///
-	/// [`TraitOptions::ENABLE_SYMBOL_RESOLVER`]: trait.SpecializedFormatterTraitOptions.html#associatedconstant.ENABLE_SYMBOL_RESOLVER
-	///
-	/// # Arguments
-	///
-	/// - `symbol_resolver`: Symbol resolver or `None`
-	#[must_use]
-	#[inline]
-	#[deprecated(since = "1.11.0", note = "This method can panic, use try_with_options() instead.")]
-	#[allow(clippy::unwrap_used)]
-	pub fn with_options(symbol_resolver: Option<Box<dyn SymbolResolver>>) -> Self {
-		SpecializedFormatter::<TraitOptions>::try_with_options(symbol_resolver).unwrap()
-	}
-
 	/// Creates a new instance of this formatter
 	///
 	/// # Errors
@@ -788,6 +816,7 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 	/// - `output`: Output
 	#[allow(clippy::missing_inline_in_public_items)]
 	#[allow(clippy::let_unit_value)]
+	#[allow(clippy::useless_let_if_seq)]
 	pub fn format(&mut self, instruction: &Instruction, output: &mut String) {
 		// SAFETY: We only append data that come from a `&str`, a `String` or ASCII chars so the data is always valid utf8
 		let dst = unsafe { output.as_mut_vec() };
@@ -804,10 +833,20 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 		if TraitOptions::use_pseudo_ops(&self.d.options) {
 			let flags = self.d.code_flags[code as usize];
 			let pseudo_ops_num = flags >> FastFmtFlags::PSEUDO_OPS_KIND_SHIFT;
-			if pseudo_ops_num != 0 && instruction.try_op_kind(op_count - 1).unwrap_or(OpKind::FarBranch16) == OpKind::Immediate8 {
+			if pseudo_ops_num != 0 && instruction.op_kind(op_count - 1) == OpKind::Immediate8 {
 				let mut index = instruction.immediate8() as usize;
 				// SAFETY: the generator generates only valid values (1-based)
 				let pseudo_ops_kind: PseudoOpsKind = unsafe { mem::transmute(pseudo_ops_num - 1) };
+				// Not enough bits to store all values so some are mapped to the same value. Fix that here.
+				let pseudo_ops_kind = if pseudo_ops_kind == PseudoOpsKind::vpcmpd6 {
+					match code {
+						#[cfg(feature = "mvex")]
+						Code::MVEX_Vpcmpud_kr_k1_zmm_zmmmt_imm8 => PseudoOpsKind::vpcmpud6,
+						_ => pseudo_ops_kind,
+					}
+				} else {
+					pseudo_ops_kind
+				};
 				let pseudo_ops = get_pseudo_ops(pseudo_ops_kind);
 				if pseudo_ops_kind == PseudoOpsKind::pclmulqdq || pseudo_ops_kind == PseudoOpsKind::vpclmulqdq {
 					if index <= 1 {
@@ -829,22 +868,25 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 
 		let prefix_seg = instruction_internal::internal_segment_prefix_raw(instruction);
 		const_assert_eq!(Register::None as u32, 0);
-		if prefix_seg < 6 || instruction_internal::internal_has_any_of_xacquire_xrelease_lock_rep_repne_prefix(instruction) != 0 {
+		if prefix_seg < 6 || instruction_internal::internal_has_any_of_lock_rep_repne_prefix(instruction) != 0 {
 			const DS_REG: u32 = Register::DS as u32 - Register::ES as u32;
 			let has_notrack_prefix = prefix_seg == DS_REG && is_notrack_prefix_branch(code);
 			if !has_notrack_prefix && prefix_seg < 6 && SpecializedFormatter::<TraitOptions>::show_segment_prefix(instruction, op_count) {
-				let prefix_seg = unsafe { mem::transmute((Register::ES as u32 + prefix_seg) as u8) };
+				let prefix_seg = unsafe { mem::transmute((Register::ES as u32 + prefix_seg) as RegisterUnderlyingType) };
 				call_format_register!(self, dst, dst_next_p, prefix_seg);
 				write_fast_ascii_char_lit!(dst, dst_next_p, ' ', true);
 			}
 
+			let mut has_xacquire_xrelease = false;
 			if instruction.has_xacquire_prefix() {
 				const FAST_STR: FastString12 = mk_const_fast_str!(FastString12, "\x09xacquire    ");
 				write_fast_str!(dst, dst_next_p, FastString12, FAST_STR);
+				has_xacquire_xrelease = true;
 			}
 			if instruction.has_xrelease_prefix() {
 				const FAST_STR: FastString12 = mk_const_fast_str!(FastString12, "\x09xrelease    ");
 				write_fast_str!(dst, dst_next_p, FastString12, FAST_STR);
+				has_xacquire_xrelease = true;
 			}
 			if instruction.has_lock_prefix() {
 				const FAST_STR: FastString8 = mk_const_fast_str!(FastString8, "\x05lock    ");
@@ -854,32 +896,34 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 				const FAST_STR: FastString8 = mk_const_fast_str!(FastString8, "\x08notrack ");
 				write_fast_str!(dst, dst_next_p, FastString8, FAST_STR);
 			}
-			if instruction.has_repe_prefix()
-				&& (SpecializedFormatter::<TraitOptions>::SHOW_USELESS_PREFIXES
-					|| show_rep_or_repe_prefix_bool(code, SpecializedFormatter::<TraitOptions>::SHOW_USELESS_PREFIXES))
-			{
-				if is_repe_or_repne_instruction(code) {
-					const FAST_STR: FastString8 = mk_const_fast_str!(FastString8, "\x05repe    ");
-					write_fast_str!(dst, dst_next_p, FastString8, FAST_STR);
-				} else {
-					const FAST_STR: FastString4 = mk_const_fast_str!(FastString4, "\x04rep ");
-					write_fast_str!(dst, dst_next_p, FastString4, FAST_STR);
+			if !has_xacquire_xrelease {
+				if instruction.has_repe_prefix()
+					&& (SpecializedFormatter::<TraitOptions>::SHOW_USELESS_PREFIXES
+						|| show_rep_or_repe_prefix_bool(code, SpecializedFormatter::<TraitOptions>::SHOW_USELESS_PREFIXES))
+				{
+					if is_repe_or_repne_instruction(code) {
+						const FAST_STR: FastString8 = mk_const_fast_str!(FastString8, "\x05repe    ");
+						write_fast_str!(dst, dst_next_p, FastString8, FAST_STR);
+					} else {
+						const FAST_STR: FastString4 = mk_const_fast_str!(FastString4, "\x04rep ");
+						write_fast_str!(dst, dst_next_p, FastString4, FAST_STR);
+					}
 				}
-			}
-			if instruction.has_repne_prefix() {
-				if (Code::Retnw_imm16 <= code && code <= Code::Retnq)
-					|| (Code::Call_rel16 <= code && code <= Code::Jmp_rel32_64)
-					|| (Code::Call_rm16 <= code && code <= Code::Call_rm64)
-					|| (Code::Jmp_rm16 <= code && code <= Code::Jmp_rm64)
-					|| code.is_jcc_short_or_near()
-				{
-					const FAST_STR: FastString4 = mk_const_fast_str!(FastString4, "\x04bnd ");
-					write_fast_str!(dst, dst_next_p, FastString4, FAST_STR);
-				} else if SpecializedFormatter::<TraitOptions>::SHOW_USELESS_PREFIXES
-					|| show_repne_prefix_bool(code, SpecializedFormatter::<TraitOptions>::SHOW_USELESS_PREFIXES)
-				{
-					const FAST_STR: FastString8 = mk_const_fast_str!(FastString8, "\x06repne   ");
-					write_fast_str!(dst, dst_next_p, FastString8, FAST_STR);
+				if instruction.has_repne_prefix() {
+					if (Code::Retnw_imm16 <= code && code <= Code::Retnq)
+						|| (Code::Call_rel16 <= code && code <= Code::Jmp_rel32_64)
+						|| (Code::Call_rm16 <= code && code <= Code::Call_rm64)
+						|| (Code::Jmp_rm16 <= code && code <= Code::Jmp_rm64)
+						|| code.is_jcc_short_or_near()
+					{
+						const FAST_STR: FastString4 = mk_const_fast_str!(FastString4, "\x04bnd ");
+						write_fast_str!(dst, dst_next_p, FastString4, FAST_STR);
+					} else if SpecializedFormatter::<TraitOptions>::SHOW_USELESS_PREFIXES
+						|| show_repne_prefix_bool(code, SpecializedFormatter::<TraitOptions>::SHOW_USELESS_PREFIXES)
+					{
+						const FAST_STR: FastString8 = mk_const_fast_str!(FastString8, "\x06repne   ");
+						write_fast_str!(dst, dst_next_p, FastString8, FAST_STR);
+					}
 				}
 			}
 		}
@@ -910,6 +954,20 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 		if op_count > 0 {
 			write_fast_ascii_char_lit!(dst, dst_next_p, ' ', true);
 
+			#[cfg(feature = "mvex")]
+			let mvex_rm_operand = {
+				if IcedConstants::is_mvex(instruction.code()) {
+					debug_assert_ne!(op_count, 0);
+					if instruction.op_kind(op_count.wrapping_sub(1)) == OpKind::Immediate8 {
+						op_count.wrapping_sub(2)
+					} else {
+						op_count.wrapping_sub(1)
+					}
+				} else {
+					u32::MAX
+				}
+			};
+
 			let mut operand = 0;
 			loop {
 				let imm8;
@@ -917,11 +975,7 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 				let imm32;
 				let imm64;
 				let imm_size;
-				let op_kind = if TraitOptions::ENABLE_DB_DW_DD_DQ && is_declare_data {
-					declare_data_kind
-				} else {
-					instruction.try_op_kind(operand).unwrap_or(OpKind::Register)
-				};
+				let op_kind = if TraitOptions::ENABLE_DB_DW_DD_DQ && is_declare_data { declare_data_kind } else { instruction.op_kind(operand) };
 
 				// Share as much code as possible so put these in macros
 				macro_rules! fmt_near_branch {
@@ -1212,6 +1266,11 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 							displ,
 							addr_size,
 						);
+						#[cfg(feature = "mvex")]
+						if instruction.is_mvex_eviction_hint() {
+							const FAST_STR: FastString4 = mk_const_fast_str!(FastString4, "\x04{eh}");
+							write_fast_str!(dst, dst_next_p, FastString4, FAST_STR);
+						}
 					}};
 				}
 
@@ -1241,7 +1300,7 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 
 						OpKind::Immediate8 | OpKind::Immediate8_2nd => {
 							if TraitOptions::ENABLE_DB_DW_DD_DQ && is_declare_data {
-								imm8 = instruction.try_get_declare_byte_value(operand as usize).unwrap_or_default();
+								imm8 = instruction.get_declare_byte_value(operand as usize);
 							} else if op_kind == OpKind::Immediate8 {
 								imm8 = instruction.immediate8();
 							} else {
@@ -1253,7 +1312,7 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 
 						OpKind::Immediate16 | OpKind::Immediate8to16 => {
 							if TraitOptions::ENABLE_DB_DW_DD_DQ && is_declare_data {
-								imm16 = instruction.try_get_declare_word_value(operand as usize).unwrap_or_default();
+								imm16 = instruction.get_declare_word_value(operand as usize);
 							} else if op_kind == OpKind::Immediate16 {
 								imm16 = instruction.immediate16();
 							} else {
@@ -1265,7 +1324,7 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 
 						OpKind::Immediate32 | OpKind::Immediate8to32 => {
 							if TraitOptions::ENABLE_DB_DW_DD_DQ && is_declare_data {
-								imm32 = instruction.try_get_declare_dword_value(operand as usize).unwrap_or_default();
+								imm32 = instruction.get_declare_dword_value(operand as usize);
 							} else if op_kind == OpKind::Immediate32 {
 								imm32 = instruction.immediate32();
 							} else {
@@ -1277,7 +1336,7 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 
 						OpKind::Immediate64 | OpKind::Immediate8to64 | OpKind::Immediate32to64 => {
 							if TraitOptions::ENABLE_DB_DW_DD_DQ && is_declare_data {
-								imm64 = instruction.try_get_declare_qword_value(operand as usize).unwrap_or_default();
+								imm64 = instruction.get_declare_qword_value(operand as usize);
 							} else if op_kind == OpKind::Immediate32to64 {
 								imm64 = instruction.immediate32to64() as u64;
 							} else if op_kind == OpKind::Immediate8to64 {
@@ -1298,8 +1357,6 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 						OpKind::MemoryESDI => fmt_memory_es_di!(),
 						OpKind::MemoryESEDI => fmt_memory_es_edi!(),
 						OpKind::MemoryESRDI => fmt_memory_es_rdi!(),
-						#[allow(deprecated)]
-						OpKind::Memory64 => {}
 						OpKind::Memory => fmt_memory!(),
 					}
 				} else {
@@ -1325,7 +1382,7 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 
 						OpKind::Immediate8 => {
 							imm8 = if TraitOptions::ENABLE_DB_DW_DD_DQ && is_declare_data {
-								instruction.try_get_declare_byte_value(operand as usize).unwrap_or_default()
+								instruction.get_declare_byte_value(operand as usize)
 							} else {
 								instruction.immediate8()
 							};
@@ -1339,7 +1396,7 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 
 						OpKind::Immediate16 => {
 							imm16 = if TraitOptions::ENABLE_DB_DW_DD_DQ && is_declare_data {
-								instruction.try_get_declare_word_value(operand as usize).unwrap_or_default()
+								instruction.get_declare_word_value(operand as usize)
 							} else {
 								instruction.immediate16()
 							};
@@ -1353,7 +1410,7 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 
 						OpKind::Immediate32 => {
 							imm32 = if TraitOptions::ENABLE_DB_DW_DD_DQ && is_declare_data {
-								instruction.try_get_declare_dword_value(operand as usize).unwrap_or_default()
+								instruction.get_declare_dword_value(operand as usize)
 							} else {
 								instruction.immediate32()
 							};
@@ -1367,7 +1424,7 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 
 						OpKind::Immediate64 => {
 							imm64 = if TraitOptions::ENABLE_DB_DW_DD_DQ && is_declare_data {
-								instruction.try_get_declare_qword_value(operand as usize).unwrap_or_default()
+								instruction.get_declare_qword_value(operand as usize)
 							} else {
 								instruction.immediate64()
 							};
@@ -1393,8 +1450,6 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 						OpKind::MemoryESDI => fmt_memory_es_di!(),
 						OpKind::MemoryESEDI => fmt_memory_es_edi!(),
 						OpKind::MemoryESRDI => fmt_memory_es_rdi!(),
-						#[allow(deprecated)]
-						OpKind::Memory64 => {}
 						OpKind::Memory => fmt_memory!(),
 					}
 				}
@@ -1410,6 +1465,18 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 						write_fast_str!(dst, dst_next_p, FastString4, FAST_STR);
 					}
 				}
+				#[cfg(feature = "mvex")]
+				if mvex_rm_operand == operand {
+					let conv = instruction.mvex_reg_mem_conv();
+					if conv != MvexRegMemConv::None {
+						let mvex = crate::mvex::get_mvex_info(instruction.code());
+						if mvex.conv_fn != MvexConvFn::None {
+							let tbl = if mvex.is_conv_fn_32() { &MVEX_REG_MEM_CONSTS_32 } else { &MVEX_REG_MEM_CONSTS_64 };
+							let s = tbl[conv as usize];
+							write_fast_str!(dst, dst_next_p, FastString12, s);
+						}
+					}
+				}
 
 				operand += 1;
 				if operand >= op_count {
@@ -1426,8 +1493,13 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 			if instruction_internal::internal_has_rounding_control_or_sae(instruction) {
 				let rc = instruction.rounding_control();
 				if rc != RoundingControl::None {
-					let fast_str = RC_STRINGS[rc as usize];
-					write_fast_str!(dst, dst_next_p, FastString8, fast_str);
+					if IcedConstants::is_mvex(instruction.code()) && !instruction.suppress_all_exceptions() {
+						let fast_str = RC_STRINGS[rc as usize];
+						write_fast_str!(dst, dst_next_p, FastString4, fast_str);
+					} else {
+						let fast_str = RC_SAE_STRINGS[rc as usize];
+						write_fast_str!(dst, dst_next_p, FastString8, fast_str);
+					}
 				} else {
 					debug_assert!(instruction.suppress_all_exceptions());
 					const FAST_STR: FastString8 = mk_const_fast_str!(FastString8, "\x05{sae}   ");
@@ -1444,7 +1516,7 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 	#[inline]
 	fn show_segment_prefix(instruction: &Instruction, op_count: u32) -> bool {
 		for i in 0..op_count {
-			match instruction.try_op_kind(i).unwrap_or(OpKind::Register) {
+			match instruction.op_kind(i) {
 				OpKind::Register
 				| OpKind::NearBranch16
 				| OpKind::NearBranch32
@@ -1464,14 +1536,12 @@ impl<TraitOptions: SpecializedFormatterTraitOptions> SpecializedFormatter<TraitO
 				| OpKind::MemoryESEDI
 				| OpKind::MemoryESRDI => {}
 
-				#[allow(deprecated)]
 				OpKind::MemorySegSI
 				| OpKind::MemorySegESI
 				| OpKind::MemorySegRSI
 				| OpKind::MemorySegDI
 				| OpKind::MemorySegEDI
 				| OpKind::MemorySegRDI
-				| OpKind::Memory64
 				| OpKind::Memory => return false,
 			}
 		}
