@@ -43,7 +43,7 @@ impl PartialEq<FormatterOptionString> for FormatterOptionString {
 impl Hash for FormatterOptionString {
 	#[inline]
 	fn hash<H: Hasher>(&self, state: &mut H) {
-		state.write(self.as_str().as_bytes());
+		self.as_str().hash(state);
 	}
 }
 
@@ -229,8 +229,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `REP stosd`
-	/// ✔️ | `false` | `rep stosd`
+	/// _ | `true` | `REP stosd`
+	/// 👍 | `false` | `rep stosd`
 	#[must_use]
 	#[inline]
 	pub fn uppercase_prefixes(&self) -> bool {
@@ -241,8 +241,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `REP stosd`
-	/// ✔️ | `false` | `rep stosd`
+	/// _ | `true` | `REP stosd`
+	/// 👍 | `false` | `rep stosd`
 	///
 	/// # Arguments
 	///
@@ -260,8 +260,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `MOV rcx,rax`
-	/// ✔️ | `false` | `mov rcx,rax`
+	/// _ | `true` | `MOV rcx,rax`
+	/// 👍 | `false` | `mov rcx,rax`
 	#[must_use]
 	#[inline]
 	pub fn uppercase_mnemonics(&self) -> bool {
@@ -272,8 +272,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `MOV rcx,rax`
-	/// ✔️ | `false` | `mov rcx,rax`
+	/// _ | `true` | `MOV rcx,rax`
+	/// 👍 | `false` | `mov rcx,rax`
 	///
 	/// # Arguments
 	///
@@ -291,8 +291,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov RCX,[RAX+RDX*8]`
-	/// ✔️ | `false` | `mov rcx,[rax+rdx*8]`
+	/// _ | `true` | `mov RCX,[RAX+RDX*8]`
+	/// 👍 | `false` | `mov rcx,[rax+rdx*8]`
 	#[must_use]
 	#[inline]
 	pub fn uppercase_registers(&self) -> bool {
@@ -303,8 +303,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov RCX,[RAX+RDX*8]`
-	/// ✔️ | `false` | `mov rcx,[rax+rdx*8]`
+	/// _ | `true` | `mov RCX,[RAX+RDX*8]`
+	/// 👍 | `false` | `mov rcx,[rax+rdx*8]`
 	///
 	/// # Arguments
 	///
@@ -322,8 +322,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov BYTE PTR [rcx],12h`
-	/// ✔️ | `false` | `mov byte ptr [rcx],12h`
+	/// _ | `true` | `mov BYTE PTR [rcx],12h`
+	/// 👍 | `false` | `mov byte ptr [rcx],12h`
 	#[must_use]
 	#[inline]
 	pub fn uppercase_keywords(&self) -> bool {
@@ -334,8 +334,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov BYTE PTR [rcx],12h`
-	/// ✔️ | `false` | `mov byte ptr [rcx],12h`
+	/// _ | `true` | `mov BYTE PTR [rcx],12h`
+	/// 👍 | `false` | `mov byte ptr [rcx],12h`
 	///
 	/// # Arguments
 	///
@@ -353,8 +353,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `vunpcklps xmm2{k5}{Z},xmm6,dword bcst [rax+4]`
-	/// ✔️ | `false` | `vunpcklps xmm2{k5}{z},xmm6,dword bcst [rax+4]`
+	/// _ | `true` | `vunpcklps xmm2{k5}{Z},xmm6,dword bcst [rax+4]`
+	/// 👍 | `false` | `vunpcklps xmm2{k5}{z},xmm6,dword bcst [rax+4]`
 	#[must_use]
 	#[inline]
 	pub fn uppercase_decorators(&self) -> bool {
@@ -365,8 +365,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `vunpcklps xmm2{k5}{Z},xmm6,dword bcst [rax+4]`
-	/// ✔️ | `false` | `vunpcklps xmm2{k5}{z},xmm6,dword bcst [rax+4]`
+	/// _ | `true` | `vunpcklps xmm2{k5}{Z},xmm6,dword bcst [rax+4]`
+	/// 👍 | `false` | `vunpcklps xmm2{k5}{z},xmm6,dword bcst [rax+4]`
 	///
 	/// # Arguments
 	///
@@ -384,8 +384,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `MOV EAX,GS:[RCX*4+0ffh]`
-	/// ✔️ | `false` | `mov eax,gs:[rcx*4+0ffh]`
+	/// _ | `true` | `MOV EAX,GS:[RCX*4+0ffh]`
+	/// 👍 | `false` | `mov eax,gs:[rcx*4+0ffh]`
 	#[must_use]
 	#[inline]
 	pub fn uppercase_all(&self) -> bool {
@@ -396,8 +396,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `MOV EAX,GS:[RCX*4+0ffh]`
-	/// ✔️ | `false` | `mov eax,gs:[rcx*4+0ffh]`
+	/// _ | `true` | `MOV EAX,GS:[RCX*4+0ffh]`
+	/// 👍 | `false` | `mov eax,gs:[rcx*4+0ffh]`
 	///
 	/// # Arguments
 	///
@@ -416,8 +416,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `0` | `mov•rcx,rbp`
-	/// &nbsp; | `8` | `mov•••••rcx,rbp`
+	/// 👍 | `0` | `mov•rcx,rbp`
+	/// _ | `8` | `mov•••••rcx,rbp`
 	#[must_use]
 	#[inline]
 	pub fn first_operand_char_index(&self) -> u32 {
@@ -429,8 +429,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `0` | `mov•rcx,rbp`
-	/// &nbsp; | `8` | `mov•••••rcx,rbp`
+	/// 👍 | `0` | `mov•rcx,rbp`
+	/// _ | `8` | `mov•••••rcx,rbp`
 	///
 	/// # Arguments
 	///
@@ -465,8 +465,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov rax, rcx`
-	/// ✔️ | `false` | `mov rax,rcx`
+	/// _ | `true` | `mov rax, rcx`
+	/// 👍 | `false` | `mov rax,rcx`
 	#[must_use]
 	#[inline]
 	pub fn space_after_operand_separator(&self) -> bool {
@@ -477,8 +477,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov rax, rcx`
-	/// ✔️ | `false` | `mov rax,rcx`
+	/// _ | `true` | `mov rax, rcx`
+	/// 👍 | `false` | `mov rax,rcx`
 	///
 	/// # Arguments
 	///
@@ -496,8 +496,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,[ rcx+rdx ]`
-	/// ✔️ | `false` | `mov eax,[rcx+rdx]`
+	/// _ | `true` | `mov eax,[ rcx+rdx ]`
+	/// 👍 | `false` | `mov eax,[rcx+rdx]`
 	#[must_use]
 	#[inline]
 	pub fn space_after_memory_bracket(&self) -> bool {
@@ -508,8 +508,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,[ rcx+rdx ]`
-	/// ✔️ | `false` | `mov eax,[rcx+rdx]`
+	/// _ | `true` | `mov eax,[ rcx+rdx ]`
+	/// 👍 | `false` | `mov eax,[rcx+rdx]`
 	///
 	/// # Arguments
 	///
@@ -527,8 +527,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,[rcx + rdx*8 - 80h]`
-	/// ✔️ | `false` | `mov eax,[rcx+rdx*8-80h]`
+	/// _ | `true` | `mov eax,[rcx + rdx*8 - 80h]`
+	/// 👍 | `false` | `mov eax,[rcx+rdx*8-80h]`
 	#[must_use]
 	#[inline]
 	pub fn space_between_memory_add_operators(&self) -> bool {
@@ -539,8 +539,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,[rcx + rdx*8 - 80h]`
-	/// ✔️ | `false` | `mov eax,[rcx+rdx*8-80h]`
+	/// _ | `true` | `mov eax,[rcx + rdx*8 - 80h]`
+	/// 👍 | `false` | `mov eax,[rcx+rdx*8-80h]`
 	///
 	/// # Arguments
 	///
@@ -558,8 +558,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,[rcx+rdx * 8-80h]`
-	/// ✔️ | `false` | `mov eax,[rcx+rdx*8-80h]`
+	/// _ | `true` | `mov eax,[rcx+rdx * 8-80h]`
+	/// 👍 | `false` | `mov eax,[rcx+rdx*8-80h]`
 	#[must_use]
 	#[inline]
 	pub fn space_between_memory_mul_operators(&self) -> bool {
@@ -570,8 +570,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,[rcx+rdx * 8-80h]`
-	/// ✔️ | `false` | `mov eax,[rcx+rdx*8-80h]`
+	/// _ | `true` | `mov eax,[rcx+rdx * 8-80h]`
+	/// 👍 | `false` | `mov eax,[rcx+rdx*8-80h]`
 	///
 	/// # Arguments
 	///
@@ -589,8 +589,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,[8*rdx]`
-	/// ✔️ | `false` | `mov eax,[rdx*8]`
+	/// _ | `true` | `mov eax,[8*rdx]`
+	/// 👍 | `false` | `mov eax,[rdx*8]`
 	#[must_use]
 	#[inline]
 	pub fn scale_before_index(&self) -> bool {
@@ -601,8 +601,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,[8*rdx]`
-	/// ✔️ | `false` | `mov eax,[rdx*8]`
+	/// _ | `true` | `mov eax,[8*rdx]`
+	/// 👍 | `false` | `mov eax,[rdx*8]`
 	///
 	/// # Arguments
 	///
@@ -620,8 +620,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,[rbx+rcx*1]`
-	/// ✔️ | `false` | `mov eax,[rbx+rcx]`
+	/// _ | `true` | `mov eax,[rbx+rcx*1]`
+	/// 👍 | `false` | `mov eax,[rbx+rcx]`
 	#[must_use]
 	#[inline]
 	pub fn always_show_scale(&self) -> bool {
@@ -632,8 +632,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,[rbx+rcx*1]`
-	/// ✔️ | `false` | `mov eax,[rbx+rcx]`
+	/// _ | `true` | `mov eax,[rbx+rcx*1]`
+	/// 👍 | `false` | `mov eax,[rbx+rcx]`
 	///
 	/// # Arguments
 	///
@@ -652,8 +652,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,ds:[ecx]`
-	/// ✔️ | `false` | `mov eax,[ecx]`
+	/// _ | `true` | `mov eax,ds:[ecx]`
+	/// 👍 | `false` | `mov eax,[ecx]`
 	#[must_use]
 	#[inline]
 	pub fn always_show_segment_register(&self) -> bool {
@@ -665,8 +665,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,ds:[ecx]`
-	/// ✔️ | `false` | `mov eax,[ecx]`
+	/// _ | `true` | `mov eax,ds:[ecx]`
+	/// 👍 | `false` | `mov eax,[ecx]`
 	///
 	/// # Arguments
 	///
@@ -684,8 +684,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,[rcx*2+0]`
-	/// ✔️ | `false` | `mov eax,[rcx*2]`
+	/// _ | `true` | `mov eax,[rcx*2+0]`
+	/// 👍 | `false` | `mov eax,[rcx*2]`
 	#[must_use]
 	#[inline]
 	pub fn show_zero_displacements(&self) -> bool {
@@ -696,8 +696,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,[rcx*2+0]`
-	/// ✔️ | `false` | `mov eax,[rcx*2]`
+	/// _ | `true` | `mov eax,[rcx*2+0]`
+	/// 👍 | `false` | `mov eax,[rcx*2]`
 	///
 	/// # Arguments
 	///
@@ -783,8 +783,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `0` | `0x12345678`
-	/// ✔️ | `4` | `0x1234_5678`
+	/// _ | `0` | `0x12345678`
+	/// 👍 | `4` | `0x1234_5678`
 	#[must_use]
 	#[inline]
 	pub fn hex_digit_group_size(&self) -> u32 {
@@ -797,8 +797,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `0` | `0x12345678`
-	/// ✔️ | `4` | `0x1234_5678`
+	/// _ | `0` | `0x12345678`
+	/// 👍 | `4` | `0x1234_5678`
 	///
 	/// # Arguments
 	///
@@ -880,8 +880,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `0` | `12345678`
-	/// ✔️ | `3` | `12_345_678`
+	/// _ | `0` | `12345678`
+	/// 👍 | `3` | `12_345_678`
 	#[must_use]
 	#[inline]
 	pub fn decimal_digit_group_size(&self) -> u32 {
@@ -894,8 +894,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `0` | `12345678`
-	/// ✔️ | `3` | `12_345_678`
+	/// _ | `0` | `12345678`
+	/// 👍 | `3` | `12_345_678`
 	///
 	/// # Arguments
 	///
@@ -977,8 +977,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `0` | `12345670`
-	/// ✔️ | `4` | `1234_5670`
+	/// _ | `0` | `12345670`
+	/// 👍 | `4` | `1234_5670`
 	#[must_use]
 	#[inline]
 	pub fn octal_digit_group_size(&self) -> u32 {
@@ -991,8 +991,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `0` | `12345670`
-	/// ✔️ | `4` | `1234_5670`
+	/// _ | `0` | `12345670`
+	/// 👍 | `4` | `1234_5670`
 	///
 	/// # Arguments
 	///
@@ -1074,8 +1074,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `0` | `11010111`
-	/// ✔️ | `4` | `1101_0111`
+	/// _ | `0` | `11010111`
+	/// 👍 | `4` | `1101_0111`
 	#[must_use]
 	#[inline]
 	pub fn binary_digit_group_size(&self) -> u32 {
@@ -1088,8 +1088,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `0` | `11010111`
-	/// ✔️ | `4` | `1101_0111`
+	/// _ | `0` | `11010111`
+	/// 👍 | `4` | `1101_0111`
 	///
 	/// # Arguments
 	///
@@ -1105,8 +1105,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `""` | `0x12345678`
-	/// &nbsp; | `"_"` | `0x1234_5678`
+	/// 👍 | `""` | `0x12345678`
+	/// _ | `"_"` | `0x1234_5678`
 	#[must_use]
 	#[inline]
 	pub fn digit_separator(&self) -> &str {
@@ -1119,8 +1119,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `""` | `0x12345678`
-	/// &nbsp; | `"_"` | `0x1234_5678`
+	/// 👍 | `""` | `0x12345678`
+	/// _ | `"_"` | `0x1234_5678`
 	///
 	/// # Arguments
 	///
@@ -1136,8 +1136,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `""` | `0x12345678`
-	/// &nbsp; | `"_"` | `0x1234_5678`
+	/// 👍 | `""` | `0x12345678`
+	/// _ | `"_"` | `0x1234_5678`
 	///
 	/// # Arguments
 	///
@@ -1153,8 +1153,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `0x0000000A`/`0000000Ah`
-	/// ✔️ | `false` | `0xA`/`0Ah`
+	/// _ | `true` | `0x0000000A`/`0000000Ah`
+	/// 👍 | `false` | `0xA`/`0Ah`
 	///
 	/// [`branch_leading_zeros`]: #method.branch_leading_zeros
 	/// [`displacement_leading_zeros`]: #method.displacement_leading_zeros
@@ -1170,8 +1170,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `0x0000000A`/`0000000Ah`
-	/// ✔️ | `false` | `0xA`/`0Ah`
+	/// _ | `true` | `0x0000000A`/`0000000Ah`
+	/// 👍 | `false` | `0xA`/`0Ah`
 	///
 	/// [`branch_leading_zeros`]: #method.branch_leading_zeros
 	/// [`displacement_leading_zeros`]: #method.displacement_leading_zeros
@@ -1205,8 +1205,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `true` | `0xFF`
-	/// &nbsp; | `false` | `0xff`
+	/// 👍 | `true` | `0xFF`
+	/// _ | `false` | `0xff`
 	#[must_use]
 	#[inline]
 	pub fn uppercase_hex(&self) -> bool {
@@ -1217,8 +1217,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `true` | `0xFF`
-	/// &nbsp; | `false` | `0xff`
+	/// 👍 | `true` | `0xFF`
+	/// _ | `false` | `0xff`
 	///
 	/// # Arguments
 	///
@@ -1236,8 +1236,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `true` | `9`
-	/// &nbsp; | `false` | `0x9`
+	/// 👍 | `true` | `9`
+	/// _ | `false` | `0x9`
 	#[must_use]
 	#[inline]
 	pub fn small_hex_numbers_in_decimal(&self) -> bool {
@@ -1248,8 +1248,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `true` | `9`
-	/// &nbsp; | `false` | `0x9`
+	/// 👍 | `true` | `9`
+	/// _ | `false` | `0x9`
 	///
 	/// # Arguments
 	///
@@ -1267,8 +1267,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `true` | `0FFh`
-	/// &nbsp; | `false` | `FFh`
+	/// 👍 | `true` | `0FFh`
+	/// _ | `false` | `FFh`
 	#[must_use]
 	#[inline]
 	pub fn add_leading_zero_to_hex_numbers(&self) -> bool {
@@ -1279,8 +1279,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `true` | `0FFh`
-	/// &nbsp; | `false` | `FFh`
+	/// 👍 | `true` | `0FFh`
+	/// _ | `false` | `FFh`
 	///
 	/// # Arguments
 	///
@@ -1323,8 +1323,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `true` | `je 00000123h`
-	/// &nbsp; | `false` | `je 123h`
+	/// 👍 | `true` | `je 00000123h`
+	/// _ | `false` | `je 123h`
 	#[must_use]
 	#[inline]
 	pub fn branch_leading_zeros(&self) -> bool {
@@ -1335,8 +1335,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `true` | `je 00000123h`
-	/// &nbsp; | `false` | `je 123h`
+	/// 👍 | `true` | `je 00000123h`
+	/// _ | `false` | `je 123h`
 	///
 	/// # Arguments
 	///
@@ -1367,8 +1367,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,-1`
-	/// ✔️ | `false` | `mov eax,FFFFFFFF`
+	/// _ | `true` | `mov eax,-1`
+	/// 👍 | `false` | `mov eax,FFFFFFFF`
 	#[must_use]
 	#[inline]
 	pub fn signed_immediate_operands(&self) -> bool {
@@ -1379,8 +1379,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,-1`
-	/// ✔️ | `false` | `mov eax,FFFFFFFF`
+	/// _ | `true` | `mov eax,-1`
+	/// 👍 | `false` | `mov eax,FFFFFFFF`
 	///
 	/// # Arguments
 	///
@@ -1398,8 +1398,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `true` | `mov al,[eax-2000h]`
-	/// &nbsp; | `false` | `mov al,[eax+0FFFFE000h]`
+	/// 👍 | `true` | `mov al,[eax-2000h]`
+	/// _ | `false` | `mov al,[eax+0FFFFE000h]`
 	#[must_use]
 	#[inline]
 	pub fn signed_memory_displacements(&self) -> bool {
@@ -1410,8 +1410,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `true` | `mov al,[eax-2000h]`
-	/// &nbsp; | `false` | `mov al,[eax+0FFFFE000h]`
+	/// 👍 | `true` | `mov al,[eax-2000h]`
+	/// _ | `false` | `mov al,[eax+0FFFFE000h]`
 	///
 	/// # Arguments
 	///
@@ -1429,8 +1429,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov al,[eax+00000012h]`
-	/// ✔️ | `false` | `mov al,[eax+12h]`
+	/// _ | `true` | `mov al,[eax+00000012h]`
+	/// 👍 | `false` | `mov al,[eax+12h]`
 	#[must_use]
 	#[inline]
 	pub fn displacement_leading_zeros(&self) -> bool {
@@ -1441,8 +1441,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov al,[eax+00000012h]`
-	/// ✔️ | `false` | `mov al,[eax+12h]`
+	/// _ | `true` | `mov al,[eax+00000012h]`
+	/// 👍 | `false` | `mov al,[eax+12h]`
 	///
 	/// # Arguments
 	///
@@ -1500,8 +1500,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,[rip+12345678h]`
-	/// ✔️ | `false` | `mov eax,[1029384756AFBECDh]`
+	/// _ | `true` | `mov eax,[rip+12345678h]`
+	/// 👍 | `false` | `mov eax,[1029384756AFBECDh]`
 	#[must_use]
 	#[inline]
 	pub fn rip_relative_addresses(&self) -> bool {
@@ -1512,8 +1512,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,[rip+12345678h]`
-	/// ✔️ | `false` | `mov eax,[1029384756AFBECDh]`
+	/// _ | `true` | `mov eax,[rip+12345678h]`
+	/// 👍 | `false` | `mov eax,[1029384756AFBECDh]`
 	///
 	/// # Arguments
 	///
@@ -1531,8 +1531,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `true` | `je short 1234h`
-	/// &nbsp; | `false` | `je 1234h`
+	/// 👍 | `true` | `je short 1234h`
+	/// _ | `false` | `je 1234h`
 	#[must_use]
 	#[inline]
 	pub fn show_branch_size(&self) -> bool {
@@ -1543,8 +1543,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `true` | `je short 1234h`
-	/// &nbsp; | `false` | `je 1234h`
+	/// 👍 | `true` | `je short 1234h`
+	/// _ | `false` | `je 1234h`
 	///
 	/// # Arguments
 	///
@@ -1562,8 +1562,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `true` | `vcmpnltsd xmm2,xmm6,xmm3`
-	/// &nbsp; | `false` | `vcmpsd xmm2,xmm6,xmm3,5`
+	/// 👍 | `true` | `vcmpnltsd xmm2,xmm6,xmm3`
+	/// _ | `false` | `vcmpsd xmm2,xmm6,xmm3,5`
 	#[must_use]
 	#[inline]
 	pub fn use_pseudo_ops(&self) -> bool {
@@ -1574,8 +1574,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `true` | `vcmpnltsd xmm2,xmm6,xmm3`
-	/// &nbsp; | `false` | `vcmpsd xmm2,xmm6,xmm3,5`
+	/// 👍 | `true` | `vcmpnltsd xmm2,xmm6,xmm3`
+	/// _ | `false` | `vcmpsd xmm2,xmm6,xmm3,5`
 	///
 	/// # Arguments
 	///
@@ -1593,8 +1593,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,[myfield (12345678)]`
-	/// ✔️ | `false` | `mov eax,[myfield]`
+	/// _ | `true` | `mov eax,[myfield (12345678)]`
+	/// 👍 | `false` | `mov eax,[myfield]`
 	#[must_use]
 	#[inline]
 	pub fn show_symbol_address(&self) -> bool {
@@ -1605,8 +1605,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,[myfield (12345678)]`
-	/// ✔️ | `false` | `mov eax,[myfield]`
+	/// _ | `true` | `mov eax,[myfield (12345678)]`
+	/// 👍 | `false` | `mov eax,[myfield]`
 	///
 	/// # Arguments
 	///
@@ -1624,8 +1624,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,ecx`
-	/// ✔️ | `false` | `mov %eax,%ecx`
+	/// _ | `true` | `mov eax,ecx`
+	/// 👍 | `false` | `mov %eax,%ecx`
 	#[must_use]
 	#[inline]
 	pub fn gas_naked_registers(&self) -> bool {
@@ -1636,8 +1636,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `mov eax,ecx`
-	/// ✔️ | `false` | `mov %eax,%ecx`
+	/// _ | `true` | `mov eax,ecx`
+	/// 👍 | `false` | `mov %eax,%ecx`
 	///
 	/// # Arguments
 	///
@@ -1655,8 +1655,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `movl %eax,%ecx`
-	/// ✔️ | `false` | `mov %eax,%ecx`
+	/// _ | `true` | `movl %eax,%ecx`
+	/// 👍 | `false` | `mov %eax,%ecx`
 	#[must_use]
 	#[inline]
 	pub fn gas_show_mnemonic_size_suffix(&self) -> bool {
@@ -1667,8 +1667,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `movl %eax,%ecx`
-	/// ✔️ | `false` | `mov %eax,%ecx`
+	/// _ | `true` | `movl %eax,%ecx`
+	/// 👍 | `false` | `mov %eax,%ecx`
 	///
 	/// # Arguments
 	///
@@ -1686,8 +1686,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `(%eax, %ecx, 2)`
-	/// ✔️ | `false` | `(%eax,%ecx,2)`
+	/// _ | `true` | `(%eax, %ecx, 2)`
+	/// 👍 | `false` | `(%eax,%ecx,2)`
 	#[must_use]
 	#[inline]
 	pub fn gas_space_after_memory_operand_comma(&self) -> bool {
@@ -1698,8 +1698,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `(%eax, %ecx, 2)`
-	/// ✔️ | `false` | `(%eax,%ecx,2)`
+	/// _ | `true` | `(%eax, %ecx, 2)`
+	/// 👍 | `false` | `(%eax,%ecx,2)`
 	///
 	/// # Arguments
 	///
@@ -1717,8 +1717,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `true` | `mov eax,ds:[12345678]`
-	/// &nbsp; | `false` | `mov eax,[12345678]`
+	/// 👍 | `true` | `mov eax,ds:[12345678]`
+	/// _ | `false` | `mov eax,[12345678]`
 	#[must_use]
 	#[inline]
 	pub fn masm_add_ds_prefix32(&self) -> bool {
@@ -1729,8 +1729,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `true` | `mov eax,ds:[12345678]`
-	/// &nbsp; | `false` | `mov eax,[12345678]`
+	/// 👍 | `true` | `mov eax,ds:[12345678]`
+	/// _ | `false` | `mov eax,[12345678]`
 	///
 	/// # Arguments
 	///
@@ -1748,8 +1748,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `true` | `[ecx+symbol]` / `[symbol]`
-	/// &nbsp; | `false` | `symbol[ecx]` / `symbol`
+	/// 👍 | `true` | `[ecx+symbol]` / `[symbol]`
+	/// _ | `false` | `symbol[ecx]` / `symbol`
 	#[must_use]
 	#[inline]
 	pub fn masm_symbol_displ_in_brackets(&self) -> bool {
@@ -1760,8 +1760,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `true` | `[ecx+symbol]` / `[symbol]`
-	/// &nbsp; | `false` | `symbol[ecx]` / `symbol`
+	/// 👍 | `true` | `[ecx+symbol]` / `[symbol]`
+	/// _ | `false` | `symbol[ecx]` / `symbol`
 	///
 	/// # Arguments
 	///
@@ -1779,8 +1779,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `true` | `[ecx+1234h]`
-	/// &nbsp; | `false` | `1234h[ecx]`
+	/// 👍 | `true` | `[ecx+1234h]`
+	/// _ | `false` | `1234h[ecx]`
 	#[must_use]
 	#[inline]
 	pub fn masm_displ_in_brackets(&self) -> bool {
@@ -1791,8 +1791,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// ✔️ | `true` | `[ecx+1234h]`
-	/// &nbsp; | `false` | `1234h[ecx]`
+	/// 👍 | `true` | `[ecx+1234h]`
+	/// _ | `false` | `1234h[ecx]`
 	///
 	/// # Arguments
 	///
@@ -1810,8 +1810,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `or rcx,byte -1`
-	/// ✔️ | `false` | `or rcx,-1`
+	/// _ | `true` | `or rcx,byte -1`
+	/// 👍 | `false` | `or rcx,-1`
 	#[must_use]
 	#[inline]
 	pub fn nasm_show_sign_extended_immediate_size(&self) -> bool {
@@ -1822,8 +1822,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `or rcx,byte -1`
-	/// ✔️ | `false` | `or rcx,-1`
+	/// _ | `true` | `or rcx,byte -1`
+	/// 👍 | `false` | `or rcx,-1`
 	///
 	/// # Arguments
 	///
@@ -1841,8 +1841,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `fadd st(0),st(3)`
-	/// ✔️ | `false` | `fadd st,st(3)`
+	/// _ | `true` | `fadd st(0),st(3)`
+	/// 👍 | `false` | `fadd st,st(3)`
 	#[must_use]
 	#[inline]
 	pub fn prefer_st0(&self) -> bool {
@@ -1853,8 +1853,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `fadd st(0),st(3)`
-	/// ✔️ | `false` | `fadd st,st(3)`
+	/// _ | `true` | `fadd st(0),st(3)`
+	/// 👍 | `false` | `fadd st,st(3)`
 	///
 	/// # Arguments
 	///
@@ -1872,8 +1872,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `es rep add eax,ecx`
-	/// ✔️ | `false` | `add eax,ecx`
+	/// _ | `true` | `es rep add eax,ecx`
+	/// 👍 | `false` | `add eax,ecx`
 	#[must_use]
 	#[inline]
 	pub fn show_useless_prefixes(&self) -> bool {
@@ -1884,8 +1884,8 @@ impl FormatterOptions {
 	///
 	/// Default | Value | Example
 	/// --------|-------|--------
-	/// &nbsp; | `true` | `es rep add eax,ecx`
-	/// ✔️ | `false` | `add eax,ecx`
+	/// _ | `true` | `es rep add eax,ecx`
+	/// 👍 | `false` | `add eax,ecx`
 	///
 	/// # Arguments
 	///
