@@ -28,7 +28,7 @@ use crate::instruction_internal;
 use crate::*;
 use alloc::boxed::Box;
 use alloc::vec::Vec;
-use core::{mem, u16, u32, u8};
+use core::mem;
 
 /// Nasm formatter
 ///
@@ -151,9 +151,7 @@ impl NasmFormatter {
 			const PREFIX_FLAGS: u32 = (InstrOpInfoFlags::SIZE_OVERRIDE_MASK << InstrOpInfoFlags::OP_SIZE_SHIFT)
 				| (InstrOpInfoFlags::SIZE_OVERRIDE_MASK << InstrOpInfoFlags::ADDR_SIZE_SHIFT)
 				| InstrOpInfoFlags::BND_PREFIX;
-			if ((prefix_seg as u32)
-				| instruction_internal::internal_has_any_of_xacquire_xrelease_lock_rep_repne_prefix(instruction)
-				| (op_info.flags & PREFIX_FLAGS))
+			if ((prefix_seg as u32) | instruction_internal::internal_has_any_of_lock_rep_repne_prefix(instruction) | (op_info.flags & PREFIX_FLAGS))
 				!= 0
 			{
 				let mut prefix;
@@ -344,6 +342,10 @@ impl NasmFormatter {
 				| InstrOpKind::RdSae
 				| InstrOpKind::RuSae
 				| InstrOpKind::RzSae
+				| InstrOpKind::Rn
+				| InstrOpKind::Rd
+				| InstrOpKind::Ru
+				| InstrOpKind::Rz
 				| InstrOpKind::DeclareByte
 				| InstrOpKind::DeclareWord
 				| InstrOpKind::DeclareDword
@@ -355,7 +357,6 @@ impl NasmFormatter {
 				| InstrOpKind::MemorySegDI
 				| InstrOpKind::MemorySegEDI
 				| InstrOpKind::MemorySegRDI
-				| InstrOpKind::Memory64
 				| InstrOpKind::Memory => return false,
 			}
 		}
@@ -390,6 +391,21 @@ impl NasmFormatter {
 	fn format_operand(&mut self, instruction: &Instruction, output: &mut dyn FormatterOutput, op_info: &InstrOpInfo<'_>, operand: u32) {
 		debug_assert!(operand < op_info.op_count as u32);
 
+		#[cfg(feature = "mvex")]
+		let mvex_rm_operand = {
+			if IcedConstants::is_mvex(instruction.code()) {
+				let op_count = instruction.op_count();
+				debug_assert_ne!(op_count, 0);
+				if instruction.op_kind(op_count.wrapping_sub(1)) == OpKind::Immediate8 {
+					op_count.wrapping_sub(2)
+				} else {
+					op_count.wrapping_sub(1)
+				}
+			} else {
+				u32::MAX
+			}
+		};
+
 		let instruction_operand = op_info.instruction_index(operand);
 
 		let flow_control;
@@ -629,7 +645,7 @@ impl NasmFormatter {
 				} else if op_kind == InstrOpKind::Immediate8_2nd {
 					imm8 = instruction.immediate8_2nd();
 				} else {
-					imm8 = instruction.try_get_declare_byte_value(operand as usize).unwrap_or_default();
+					imm8 = instruction.get_declare_byte_value(operand as usize);
 				}
 				operand_options = FormatterOperandOptions::default();
 				let mut number_options = NumberFormattingOptions::with_immediate(&self.d.options);
@@ -677,7 +693,7 @@ impl NasmFormatter {
 				} else if op_kind == InstrOpKind::Immediate8to16 {
 					imm16 = instruction.immediate8to16() as u16;
 				} else {
-					imm16 = instruction.try_get_declare_word_value(operand as usize).unwrap_or_default();
+					imm16 = instruction.get_declare_word_value(operand as usize);
 				}
 				operand_options = FormatterOperandOptions::default();
 				let mut number_options = NumberFormattingOptions::with_immediate(&self.d.options);
@@ -725,7 +741,7 @@ impl NasmFormatter {
 				} else if op_kind == InstrOpKind::Immediate8to32 {
 					imm32 = instruction.immediate8to32() as u32;
 				} else {
-					imm32 = instruction.try_get_declare_dword_value(operand as usize).unwrap_or_default();
+					imm32 = instruction.get_declare_dword_value(operand as usize);
 				}
 				operand_options = FormatterOperandOptions::default();
 				let mut number_options = NumberFormattingOptions::with_immediate(&self.d.options);
@@ -775,7 +791,7 @@ impl NasmFormatter {
 				} else if op_kind == InstrOpKind::Immediate64 {
 					imm64 = instruction.immediate64();
 				} else {
-					imm64 = instruction.try_get_declare_qword_value(operand as usize).unwrap_or_default();
+					imm64 = instruction.get_declare_qword_value(operand as usize);
 				}
 				operand_options = FormatterOperandOptions::default();
 				let mut number_options = NumberFormattingOptions::with_immediate(&self.d.options);
@@ -950,7 +966,6 @@ impl NasmFormatter {
 				8,
 				op_info.flags,
 			),
-			InstrOpKind::Memory64 => {}
 
 			InstrOpKind::Memory => {
 				let displ_size = instruction.memory_displ_size();
@@ -1020,6 +1035,42 @@ impl NasmFormatter {
 				&self.d.str_.rz_sae,
 				DecoratorKind::RoundingControl,
 			),
+			InstrOpKind::Rn => NasmFormatter::format_decorator(
+				&self.d.options,
+				output,
+				instruction,
+				operand,
+				instruction_operand,
+				&self.d.str_.rn,
+				DecoratorKind::RoundingControl,
+			),
+			InstrOpKind::Rd => NasmFormatter::format_decorator(
+				&self.d.options,
+				output,
+				instruction,
+				operand,
+				instruction_operand,
+				&self.d.str_.rd,
+				DecoratorKind::RoundingControl,
+			),
+			InstrOpKind::Ru => NasmFormatter::format_decorator(
+				&self.d.options,
+				output,
+				instruction,
+				operand,
+				instruction_operand,
+				&self.d.str_.ru,
+				DecoratorKind::RoundingControl,
+			),
+			InstrOpKind::Rz => NasmFormatter::format_decorator(
+				&self.d.options,
+				output,
+				instruction,
+				operand,
+				instruction_operand,
+				&self.d.str_.rz,
+				DecoratorKind::RoundingControl,
+			),
 		}
 
 		if operand == 0 && instruction_internal::internal_has_op_mask_or_zeroing_masking(instruction) {
@@ -1040,6 +1091,20 @@ impl NasmFormatter {
 				);
 			}
 		}
+		#[cfg(feature = "mvex")]
+		if mvex_rm_operand == operand {
+			let conv = instruction.mvex_reg_mem_conv();
+			if conv != MvexRegMemConv::None {
+				let mvex = crate::mvex::get_mvex_info(instruction.code());
+				if mvex.conv_fn != MvexConvFn::None {
+					let tbl = if mvex.is_conv_fn_32() { &self.d.vec_.mvex_reg_mem_consts_32 } else { &self.d.vec_.mvex_reg_mem_consts_64 };
+					let s = tbl[conv as usize];
+					if s.len() != 0 {
+						Self::format_decorator(&self.d.options, output, instruction, operand, instruction_operand, s, DecoratorKind::SwizzleMemConv);
+					}
+				}
+			}
+		}
 	}
 
 	fn show_sign_extend_info(d: &SelfData, output: &mut dyn FormatterOutput, flags: u32) {
@@ -1377,6 +1442,18 @@ impl NasmFormatter {
 		if !bcst_to.is_default() {
 			NasmFormatter::format_decorator(&self.d.options, output, instruction, operand, instruction_operand, bcst_to, DecoratorKind::Broadcast);
 		}
+		#[cfg(feature = "mvex")]
+		if instruction.is_mvex_eviction_hint() {
+			Self::format_decorator(
+				&self.d.options,
+				output,
+				instruction,
+				operand,
+				instruction_operand,
+				&self.d.str_.mvex.eh,
+				DecoratorKind::EvictionHint,
+			);
+		}
 	}
 
 	fn format_memory_size(
